@@ -34,7 +34,7 @@ class TestMainLoop(unittest.TestCase):
             raise Exception("deadbabe")
 
         loop = GLib.MainLoop()
-        GLib.child_watch_add(pid, child_died, loop)
+        GLib.child_watch_add(GLib.PRIORITY_DEFAULT, pid, child_died, loop)
 
         os.close(pipe_r)
         os.write(pipe_w, _bytes("Y"))
@@ -79,3 +79,19 @@ class TestMainLoop(unittest.TestCase):
             loop2.quit()
         finally:
             signal.signal(signal.SIGUSR1, orig_handler)
+
+    def test_sigint(self):
+        pid = os.fork()
+        if pid == 0:
+            time.sleep(0.5)
+            os.kill(os.getppid(), signal.SIGINT)
+            os._exit(0)
+
+        loop = GLib.MainLoop()
+        try:
+            loop.run()
+            self.fail('expected KeyboardInterrupt exception')
+        except KeyboardInterrupt:
+            pass
+        self.assertFalse(loop.is_running())
+        os.waitpid(pid, 0)
